function y = alogn(rho, H, nu0, eps0, nu)
%ALOGN Asymmetric log-normal function.
%   Y = ALOGN(RHO, H, NU0, EPS0, NU) is the asymmetric
%   log-normal function with aymmetry RHO, full width
%   at half maximum H, center NU0 and height EPS0, evaluated
%   at the elements of vector NU.
%
%   AUTHOR:
%      Wouter Caarls, MPIbpc <wouter@caarls.org>

  rho = abs(rho);
  H = abs(H);
  nu0 = abs(nu0);
  eps0 = abs(eps0);
  
  if rho == 1
    rho = 1.001;
  end

  if rho <= 1
    rho = 1/rho;
    nu = -nu;
    nu0 = -nu0;
  end
  
  y = eps0 .* exp(-((log(2)./(log(rho).^2)).*log(((nu-nu0)./H).*((rho.^2-1)/rho)+1).^2));
  
  y(nu < (nu0-(H*rho)/(rho^2-1))) = 0;
  
