function desc = fluofitdesc(data, em, ex, opt)
%FLUOFITDESC Fluorescence spectra description.
%   DESC = FLUOFITDESC(DATA, EM, EX, OPT) generates a description
%   of the fluorescence spectra by packing together the
%   DATA, EM emission wavelengths and EX excitation wavelengths.
%
%   EXAMPLE:
%      desc = fluofitdesc(data, em, ex, opt);
%
%   AUTHOR:
%      Wouter Caarls, MPIbpc <wouter@caarls.org>

    if size(em, 1) > size(em, 2)
        em = em';
    end

    desc.data = data;
    
    if opt.wavenumber
        desc.em = 10^7./em;
        desc.ex = 10^7./ex;
    else
        desc.em = em;
        desc.ex = ex;
    end
        
    desc.reps = size(data, 3);

end
